@@ -152,9 +152,11 @@ class FileShelf(Shelf):
                 exist = True
                 break
 
-        # if it does not, add it to the first Box
-        if not exist:
-            self.boxes[0][unicode(name)] = open(document)
+        # if it does not, add it to the first writable Box
+        for box in self.boxes:
+            if box.readable:
+                box[0][unicode(name)] = open(document)
+                break
 
         # We return the name of the newly created doc
         return name
@@ -175,8 +177,9 @@ class FileShelf(Shelf):
         if not purge:
             return
 
+        # We need to remove the doc is box is writable
         for box in self.boxes:
-            if box.haskey(name):
+            if box.haskey(name) and not box.readonly:
                 del(box[name])
 
     def modify(self, name, metadata):
@@ -241,6 +244,15 @@ def ShelfOfShelves(Shelf)
     readonly = True
     library = []
 
+    def __init__(self, shelves_list=[]):
+        """
+        Let's initialize our library.
+
+        shelves_list is a list of already created shelves that we wanna add
+        """
+        for shelf in shelves_list:
+            self.__add_shelg(self, shelf)
+
     def __add_shelf(self, shelf):
         """
         Let's add a new shelf to our library.
